#!/bin/bash

set -e

# get the root of the git repository (requires git to be installed)
GIT_ROOT=$(git rev-parse --show-toplevel)
cd "$GIT_ROOT"

# define useful variables
source generation/00env.sh

CERT_DIR=uefi-keys/public-certificates
KEYS_DIR=uefi-keys/private-keys
PUBLIC_CERT_DIR=${PROJECT_DIR}/${CERT_DIR}/${SERVER_GROUP}
PRIVATE_KEYS_DIR=${PROJECT_DIR}/${KEYS_DIR}/${SERVER_GROUP}
dracut_output_file=dracut-output

# Install the module
cd dracut.module
./configure
make uninstall clean
make install
cd -

# Generation of dracut.module/dracut.conf
dracut_conf_regex="s|%PROJECT_DIR%|${PROJECT_DIR}|g;s|%PUBLIC_CERT_DIR%|${PUBLIC_CERT_DIR}|g;s|%PRIVATE_KEYS_DIR%|${PRIVATE_KEYS_DIR}|g;s|%CERT_NAME%|${CERT_NAME}|;s|%SIGNING_KEY_NAME%|${SIGNING_KEY_NAME}|g;s|%ROOT_PARTITION_ID%|${ROOT_PARTITION_ID}|g;s|%DEFAULT_INTERFACE%|${DEFAULT_INTERFACE}|g;s|%DEFAULT_ROUTER%|${DEFAULT_ROUTER}|g;s|%DEFAULT_IP%|${DEFAULT_IP}|g;s|%FORMATTED_NETMASK%|${FORMATTED_NETMASK}|g;s|%TARGET_HOSTNAME%|${TARGET_HOSTNAME}|g;s|%KERNEL_IMAGE%|${KERNEL_IMAGE}|g;s|%DRIVERS_DIR%|${DRIVERS_DIR}|g"
cd dracut.module
sed "${dracut_conf_regex}" dracut.conf.in > dracut.conf
cd -

# Add files in initramfs
INCLUDE_DIR=files-to-include
rm -rf "$INCLUDE_DIR"
mkdir -p "$INCLUDE_DIR"
cp -r "$KERNEL_DIR"/lib "$INCLUDE_DIR"
export DRACUT_KMODDIR_OVERRIDE=1

# Create an initramfs image
rm -f "$dracut_output_file"
dracut "$UEFI_IMAGE_NAME" "$KERNEL_VERSION"-amd64 -c ./dracut.module/dracut.conf --force |& tee -a "$dracut_output_file"
echo New initramfs image: $(pwd)/"$UEFI_IMAGE_NAME"
